@@ -28,9 +28,4 @@ class Auto_Reaction(c.Cog, name="リアクション"):
             try:
                 await mes.add_reaction(emoji)
             except errors.HTTPException:
-                pass
-
-
-def setup(bot):
-    bot.add_cog(Auto_Reaction(bot))
-    bot.add_table(auto_reaction_table)
\ No newline at end of file
+                pass
\ No newline at end of file
